@@ -3,10 +3,12 @@
 #' 8 Hex RGB color definitions suitable for charts for colorblind people.
 #'
 #' @export
-color_blind <- function(){
-    c("#000000", "#E69F00", "#56B4E9",
-      "#009E73", "#F0E442", "#0072B2",
-      "#D55E00", "#CC79A7")
+color_blind <- function() {
+  c(
+    "#000000", "#E69F00", "#56B4E9",
+    "#009E73", "#F0E442", "#0072B2",
+    "#D55E00", "#CC79A7"
+  )
 }
 
 #' Provide Colorblind Compliant Colors
@@ -16,12 +18,11 @@ color_blind <- function(){
 #'
 #' @export
 td_scale_fill_colorblind <- function(..., theme = "td") {
+  pal <- switch(theme,
+    "td" = unname(color_blind()) %>% rep(100)
+  )
 
-    pal <- switch(theme,
-                  "td" = unname(color_blind()) %>% rep(100)
-    )
-
-    ggplot2::scale_fill_manual(values = pal)
+  ggplot2::scale_fill_manual(values = pal)
 }
 
 #' Provide Colorblind Compliant Colors
@@ -30,11 +31,10 @@ td_scale_fill_colorblind <- function(..., theme = "td") {
 #' @param ... Data passed to the function
 #'
 #' @export
-td_scale_color_colorblind = function(..., theme = "td") {
+td_scale_color_colorblind <- function(..., theme = "td") {
+  pal <- switch(theme,
+    "td" = unname(color_blind()) %>% rep(100)
+  )
 
-    pal <- switch(theme,
-                  "td" = unname(color_blind()) %>% rep(100)
-    )
-
-    ggplot2::scale_color_manual(values = pal)
+  ggplot2::scale_color_manual(values = pal)
 }
